@@ -7,6 +7,7 @@ Implements a client class to query the
 from __future__ import unicode_literals, absolute_import
 
 import requests
+from six import text_type, iteritems
 from six.moves.urllib.parse import urlencode
 
 from deezer.resources import Album, Artist, Comment, Genre
@@ -32,32 +33,32 @@ class Client(object):
     host = "api.deezer.com"
 
     objects_types = {
-        'album': Album,
-        'artist': Artist,
-        'comment': Comment,
-        'editorial': None,
+        "album": Album,
+        "artist": Artist,
+        "comment": Comment,
+        "editorial": None,
         # 'folder': None, # need identification
-        'genre': Genre,
-        'playlist': Playlist,
-        'radio': Radio,
-        'search': None,
-        'track': Track,
-        'user': User,
-        'chart': Chart
+        "genre": Genre,
+        "playlist": Playlist,
+        "radio": Radio,
+        "search": None,
+        "track": Track,
+        "user": User,
+        "chart": Chart,
     }
 
     def __init__(self, **kwargs):
         super(Client, self).__init__()
 
-        self.use_ssl = kwargs.get('use_ssl', self.use_ssl)
-        self.host = kwargs.get('host', self.host)
+        self.use_ssl = kwargs.get("use_ssl", self.use_ssl)
+        self.host = kwargs.get("host", self.host)
         self.session = requests.Session()
         self.options = kwargs
         self._authorize_url = None
 
-        self.app_id = kwargs.get('app_id')
-        self.app_secret = kwargs.get('app_secret')
-        self.access_token = kwargs.get('access_token')
+        self.app_id = kwargs.get("app_id")
+        self.app_secret = kwargs.get("app_secret")
+        self.access_token = kwargs.get("access_token")
 
     def _process_json(self, item, parent=None):
         """
@@ -66,46 +67,33 @@ class Client(object):
 
         :returns: instance of :class:`~deezer.resources.Resource`
         """
-        if 'data' in item:
-            return [self._process_json(i, parent) for i in item['data']]
+        if "data" in item:
+            return [self._process_json(i, parent) for i in item["data"]]
 
         result = {}
         for key, value in item.items():
-            if isinstance(value, dict) and ('type' in value or 'data' in value):
+            if isinstance(value, dict) and ("type" in value or "data" in value):
                 value = self._process_json(value, parent)
             result[key] = value
-        if parent is not None and hasattr(parent, 'type'):
+        if parent is not None and hasattr(parent, "type"):
             result[parent.type] = parent
 
-        if 'type' in result:
-            object_class = self.objects_types.get(result['type'], Resource)
+        if "type" in result:
+            object_class = self.objects_types.get(result["type"], Resource)
         else:
             object_class = self.objects_types.get(parent, Resource)
         return object_class(self, result)
 
-    @staticmethod
-    def make_str(value):
-        """
-        Convert value to str in python2 and python3 compatible way
-
-        :returns: str instance
-        """
-        try:  # pragma: no cover - python 3
-            value = str(value)
-        except UnicodeEncodeError:  # pragma: no cover - python 2
-            value = value.encode('utf-8')
-        return value
-
     @property
     def scheme(self):
         """
         Get the http prefix for the address depending on the use_ssl attribute
         """
-        return self.use_ssl and 'https' or 'http'
+        return self.use_ssl and "https" or "http"
 
-    def url(self, request=''):
+    def url(self, request=""):
         """Build the url with the appended request if provided."""
-        if request.startswith('/'):
+        if request.startswith("/"):
             request = request[1:]
         return "{0}://{1}/{2}".format(self.scheme, self.host, request)
 
@@ -118,24 +106,27 @@ class Client(object):
         """
         if object_t not in self.objects_types:
             raise TypeError("{0} is not a valid type".format(object_t))
-        request_items = (object_t, object_id, relation)
-        request_items = (item for item in request_items if item is not None)
-        request_items = (str(item) for item in request_items)
-        request = '/'.join(request_items)
+        request_items = (
+            text_type(item)
+            for item in [object_t, object_id, relation]
+            if item is not None
+        )
+        request = "/".join(request_items)
         base_url = self.url(request)
         if self.access_token is not None:
-            kwargs['access_token'] = self.make_str(self.access_token)
+            kwargs["access_token"] = text_type(self.access_token)
         if kwargs:
-            for key, value in kwargs.items():
+            for key, value in iteritems(kwargs):
                 if not isinstance(value, str):
-                    kwargs[key] = self.make_str(value)
-            result = '{0}?{1}'.format(base_url, urlencode(kwargs))
+                    kwargs[key] = text_type(value)
+            result = "{0}?{1}".format(base_url, urlencode(kwargs))
         else:
             result = base_url
         return result
 
-    def get_object(self, object_t, object_id=None, relation=None, parent=None,
-                   **kwargs):
+    def get_object(
+        self, object_t, object_id=None, relation=None, parent=None, **kwargs
+    ):
         """
         Actually query the Deezer API to retrieve the object
 
@@ -145,14 +136,15 @@ class Client(object):
         response = self.session.get(url)
         return self._process_json(response.json(), parent)
 
-    def get_chart(self, relation=None, **kwargs):
+    def get_chart(self, relation=None, index=0, limit=10, **kwargs):
         """
         Get chart
 
         :returns: a list of :class:`~deezer.resources.Resource` objects.
         """
-        return self.get_object("chart", object_id='0', relation=relation,
-                               parent="chart", **kwargs)
+        return self.get_object(
+            "chart", object_id="0", relation=relation, parent="chart", **kwargs
+        )
 
     def get_album(self, object_id, relation=None, **kwargs):
         """
@@ -240,7 +232,7 @@ class Client(object):
         """
         return self.get_object("user", object_id)
 
-    def search(self, query, relation=None, **kwargs):
+    def search(self, query, relation=None, index=0, limit=25, **kwargs):
         """
         Search track, album, artist or user
 
